@@ -1,6 +1,6 @@
 #!/bin/sh
 
-# Copyright 2006-2019 Intel Corporation.
+# Copyright 2006-2020 Intel Corporation.
 #
 # This software and the related documents are Intel copyrighted materials,
 # and your use of them is governed by the express license under which they
@@ -163,7 +163,7 @@ parse_cmd_parameters()
         # skip cpu checking
         skip_cpu_check="yes"
         ;;
-    --cli-mode)
+    --cli-mode|--cli_mode)
         # don't start GUI installer
         skip_gui_install="yes"
         cli_mode_params="--cli-mode"
@@ -303,7 +303,7 @@ thisexec=`basename "$0"`
 thisdir=`dirname "$0"`
 [ -z "$HOSTNAME" ] && HOSTNAME=$(hostname);
 skip_gui_install="yes"
-suite_guid="1548933241021"
+suite_guid="1602678278727"
 root_added_to_xhost_acl="no"
 
 trap "" TSTP # Disable Ctrl-Z
@@ -548,7 +548,13 @@ if [ "yes" != "${skip_gui_install}" ]; then
         fi
     fi
     check_display
-    "$pset_engine_binary" --tmp_dir "$user_tmp" --TEMP_FOLDER "$temp_folder" --download_dir "$download_tmp" $params $root_nonroot 2>/dev/null
+    ( "$pset_engine_binary" --tmp_dir "$user_tmp" --TEMP_FOLDER "$temp_folder" --download_dir "$download_tmp" $params $root_nonroot 2>/dev/null
+    ecode=$? 
+    if [ "$ecode" = "134" ]; then
+        exit $EXIT_CODE_GUI_RUN_ERROR
+    fi
+    exit $ecode
+    ) 2>/dev/null
     exit_code=$?
 else
     if [ "$cli_mode_params" = "--cli-mode" ]; then
