@@ -1,6 +1,6 @@
 #!/bin/bash
 #===============================================================================
-# Copyright 2001-2019 Intel Corporation.
+# Copyright 2001-2020 Intel Corporation.
 #
 # This software and the related documents are Intel copyrighted  materials,  and
 # your use of  them is  governed by the  express license  under which  they were
@@ -13,7 +13,8 @@
 # License.
 #===============================================================================
 
-echo    This is a SAMPLE build script for Intel\(R\) Distribution for LINPACK Benchmark.
+echo    This is a SAMPLE build script for Intel\(R\) Distribution for LINPACK\* Benchmark.
+echo         \* Other names and brands may be claimed as the property of others.
 
 if [ -z "${MKLROOT+x}" ]; then 
 MKLROOT=../..
