@@ -1,5 +1,5 @@
 /*******************************************************************************
-* Copyright 1999-2019 Intel Corporation.
+* Copyright 1999-2020 Intel Corporation.
 *
 * This software and the related documents are Intel copyrighted  materials,  and
 * your use of  them is  governed by the  express license  under which  they were
@@ -46,5 +46,7 @@
 #include "mkl_solvers_ee.h"
 #include "mkl_direct_call.h"
 #include "mkl_compact.h"
+#include "mkl_graph.h"
+#include "mkl_sparse_qr.h"
 
 #endif /* _MKL_H_ */
