@@ -1,5 +1,5 @@
 /*******************************************************************************
-* Copyright 1999-2019 Intel Corporation.
+* Copyright 1999-2020 Intel Corporation.
 *
 * This software and the related documents are Intel copyrighted  materials,  and
 * your use of  them is  governed by the  express license  under which  they were
@@ -97,6 +97,9 @@ struct {
 #ifndef MKL_INT16
     #define MKL_INT16 short
 #endif
+#ifndef MKL_BF16
+    #define MKL_BF16 unsigned short
+#endif
 #ifndef MKL_INT32
     #define MKL_INT32 int
 #endif
