@@ -1,5 +1,5 @@
 /*******************************************************************************
-* Copyright 2006-2019 Intel Corporation.
+* Copyright 2006-2020 Intel Corporation.
 *
 * This software and the related documents are Intel copyrighted  materials,  and
 * your use of  them is  governed by the  express license  under which  they were
@@ -16,7 +16,8 @@
 !   Content:
 !       Wrapper library building. Functions rfftw2d_mpi_create_plan,
 !	rfftw3d_mpi_create_plan, rfftwnd_mpi_create_plan.
-!       This library allows to use Intel(R) MKL CDFT routines through MPI FFTW interface.
+!       This library allows to use Intel(R) Math Kernel Library (Intel(R) MKL)
+!       CDFT routines through MPI FFTW interface.
 !******************************************************************************/
 
 #include "common.h"
