@@ -1,5 +1,5 @@
 /*******************************************************************************
-* Copyright 2006-2019 Intel Corporation.
+* Copyright 2006-2020 Intel Corporation.
 *
 * This software and the related documents are Intel copyrighted  materials,  and
 * your use of  them is  governed by the  express license  under which  they were
@@ -15,7 +15,8 @@
 /*
 !   Content:
 !       Wrapper library building. Function rfftwnd_mpi_destroy_plan.
-!       This library allows to use Intel(R) MKL CDFT routines through MPI FFTW interface.
+!       This library allows to use Intel(R) Math Kernel Library (Intel(R) MKL)
+!       CDFT routines through MPI FFTW interface.
 !******************************************************************************/
 
 #include "common.h"
