@@ -1,5 +1,5 @@
 /*******************************************************************************
-* Copyright 2006-2019 Intel Corporation.
+* Copyright 2006-2020 Intel Corporation.
 *
 * This software and the related documents are Intel copyrighted  materials,  and
 * your use of  them is  governed by the  express license  under which  they were
@@ -14,7 +14,7 @@
 
 /*
  *
- * rfftw - FFTW2 wrapper to Intel(R) MKL.
+ * rfftw - FFTW2 wrapper to Intel(R) Math Kernel Library (Intel(R) MKL).
  *
  ******************************************************************************
  */
@@ -22,7 +22,7 @@
 #include "fftw2_mkl.h"
 
 /* This function is not implemented because
- * Intel(R) MKL DFTI doesn't support half-complex data layout.
+ * Intel MKL DFTI doesn't support half-complex data layout.
  */
 void
 rfftw(rfftw_plan plan, int howmany, fftw_real *in, int istride, int idist,
@@ -37,5 +37,5 @@ rfftw(rfftw_plan plan, int howmany, fftw_real *in, int istride, int idist,
     UNUSED(ostride);
     UNUSED(odist);
     fftw_die("rfftw() is not implemented "
-            "because Intel(R) MKL DFTI doesn't support half-complex data layout");
+            "because Intel MKL DFTI doesn't support half-complex data layout");
 }
