@@ -1,6 +1,6 @@
 #if 0
 /*******************************************************************************
-* Copyright 2015-2019 Intel Corporation.
+* Copyright 2015-2020 Intel Corporation.
 *
 * This software and the related documents are Intel copyrighted  materials,  and
 * your use of  them is  governed by the  express license  under which  they were
@@ -69,16 +69,13 @@
 #define MPI_UNDEFINED           MKLMPI_UNDEFINED
 #define MPI_UNEQUAL             MKLMPI_UNEQUAL
 #define MPI_UNSIGNED_SHORT      MKLMPI_UNSIGNED_SHORT
-#define MPI_UB                  MKLMPI_UB
 #undef COMMENT /*functions*/
 #define MPI_Abort               MKLMPI_Abort
-#define MPI_Address             MKLMPI_Address
 #define MPI_Allgather           MKLMPI_Allgather
 #define MPI_Allgatherv          MKLMPI_Allgatherv
 #define MPI_Allreduce           MKLMPI_Allreduce
 #define MPI_Alltoall            MKLMPI_Alltoall
 #define MPI_Alltoallv           MKLMPI_Alltoallv
-#define MPI_Attr_get            MKLMPI_Attr_get
 #define MPI_Barrier             MKLMPI_Barrier
 #define MPI_Bcast               MKLMPI_Bcast
 #define MPI_Cart_create         MKLMPI_Cart_create
@@ -89,6 +86,7 @@
 #define MPI_Comm_dup            MKLMPI_Comm_dup
 #define MPI_Comm_f2c            MKLMPI_Comm_f2c
 #define MPI_Comm_free           MKLMPI_Comm_free
+#define MPI_Comm_get_attr       MKLMPI_Comm_get_attr
 #define MPI_Comm_group          MKLMPI_Comm_group
 #define MPI_Comm_rank           MKLMPI_Comm_rank
 #define MPI_Comm_size           MKLMPI_Comm_size
@@ -96,6 +94,7 @@
 #define MPI_Error_class         MKLMPI_Error_class
 #define MPI_Finalize            MKLMPI_Finalize
 #define MPI_Gatherv             MKLMPI_Gatherv
+#define MPI_Get_address         MKLMPI_Get_address
 #define MPI_Group_free          MKLMPI_Group_free
 #define MPI_Group_incl          MKLMPI_Group_incl
 #define MPI_Init                MKLMPI_Init
@@ -118,13 +117,14 @@
 #define MPI_Test                MKLMPI_Test
 #define MPI_Testall             MKLMPI_Testall
 #define MPI_Type_c2f            MKLMPI_Type_c2f
+#define MPI_Type_create_struct  MKLMPI_Type_create_struct
 #define MPI_Type_commit         MKLMPI_Type_commit
 #define MPI_Type_contiguous     MKLMPI_Type_contiguous
 #define MPI_Type_f2c            MKLMPI_Type_f2c
 #define MPI_Type_free           MKLMPI_Type_free
 #define MPI_Type_indexed        MKLMPI_Type_indexed
-#define MPI_Type_struct         MKLMPI_Type_struct
 #define MPI_Type_vector         MKLMPI_Type_vector
+#define MPI_Type_create_resized MKLMPI_Type_create_resized
 #define MPI_Unpack              MKLMPI_Unpack
 #define MPI_Wait                MKLMPI_Wait
 #define MPI_Waitall             MKLMPI_Waitall
@@ -165,7 +165,6 @@
 #define MKLMPI_UNDEFINED          (XMPI_BASE + 26)
 #define MKLMPI_UNEQUAL            (XMPI_BASE + 27)
 #define MKLMPI_UNSIGNED_SHORT     (XMPI_BASE + 28)
-#define MKLMPI_UB                 (XMPI_BASE + 29)
 
 #if !defined(MKLMPI_OMIT_C_DECLARATIONS)
 
@@ -204,13 +203,11 @@ struct MKLMPI__Status_s
 };
 
 int MKLMPI_Abort(MKLMPI_Comm,int);
-int MKLMPI_Address(void *, MKLMPI_Aint *);
 int MKLMPI_Allgather(const void*,int,MKLMPI_Datatype,void*,int,MKLMPI_Datatype,MKLMPI_Comm);
 int MKLMPI_Allgatherv(const void*,int,MKLMPI_Datatype,void*,const int*,const int*,MKLMPI_Datatype,MKLMPI_Comm);
 int MKLMPI_Allreduce(void*,void*,int,MKLMPI_Datatype,MKLMPI_Op,MKLMPI_Comm);
 int MKLMPI_Alltoall(const void*,int,MKLMPI_Datatype,void*,int,MKLMPI_Datatype,MKLMPI_Comm);
 int MKLMPI_Alltoallv(const void*,const int*,const int*,MKLMPI_Datatype,void*,const int*,const int*,MKLMPI_Datatype,MKLMPI_Comm);
-int MKLMPI_Attr_get(MKLMPI_Comm,int,void*,int*);
 int MKLMPI_Barrier(MKLMPI_Comm);
 int MKLMPI_Bcast(void*,int,MKLMPI_Datatype,int,MKLMPI_Comm);
 int MKLMPI_Cart_create(MKLMPI_Comm,int,const int*,const int*,int,MKLMPI_Comm*);
@@ -221,6 +218,7 @@ int MKLMPI_Comm_create(MKLMPI_Comm,MKLMPI_Group,MKLMPI_Comm*);
 int MKLMPI_Comm_dup(MKLMPI_Comm,MKLMPI_Comm*);
 MKLMPI_Comm MKLMPI_Comm_f2c(MKLMPI_Fint);
 int MKLMPI_Comm_free(MKLMPI_Comm*);
+int MKLMPI_Comm_get_attr(MKLMPI_Comm,int,void*,int*);
 int MKLMPI_Comm_group(MKLMPI_Comm,MKLMPI_Group*);
 int MKLMPI_Comm_rank(MKLMPI_Comm,int*);
 int MKLMPI_Comm_size(MKLMPI_Comm,int*);
@@ -228,6 +226,7 @@ int MKLMPI_Comm_split(MKLMPI_Comm,int,int,MKLMPI_Comm*);
 int MKLMPI_Error_class(int,int*);
 int MKLMPI_Finalize(void);
 int MKLMPI_Gatherv(const void*,int,MKLMPI_Datatype,void*,const int*,const int*,MKLMPI_Datatype,int,MKLMPI_Comm);
+int MKLMPI_Get_address(void *, MKLMPI_Aint *);
 int MKLMPI_Group_free(MKLMPI_Group*);
 int MKLMPI_Group_incl(MKLMPI_Group,int,const int*,MKLMPI_Group*);
 int MKLMPI_Init(int*,char***);
@@ -256,9 +255,8 @@ int MKLMPI_Type_contiguous(int,MKLMPI_Datatype,MKLMPI_Datatype*);
 MKLMPI_Datatype MKLMPI_Type_f2c(MKLMPI_Fint);
 int MKLMPI_Type_free(MKLMPI_Datatype*);
 int MKLMPI_Type_indexed(int,const int*,const int*,MKLMPI_Datatype,MKLMPI_Datatype*);
-int MKLMPI_Type_struct(int,int*,MKLMPI_Aint*,MKLMPI_Datatype*,MKLMPI_Datatype*)
-    MKLMPI1DEPRECATED("MPI_Type_struct is deprecated, use MPI_Type_create_struct");
 int MKLMPI_Type_vector(int,int,int,MKLMPI_Datatype,MKLMPI_Datatype*);
+int MKLMPI_Type_create_resized(MKLMPI_Datatype,MKLMPI_Aint,MKLMPI_Aint,MKLMPI_Datatype*);
 int MKLMPI_Unpack(const void*,int,int*,void*,int,MKLMPI_Datatype,MKLMPI_Comm);
 int MKLMPI_Wait(MKLMPI_Request*,MKLMPI_Status*);
 int MKLMPI_Waitall(int,MKLMPI_Request*,MKLMPI_Status*);
